@@ -1,4 +1,4 @@
-# $Id: search.rb,v 1.132 2005/03/02 08:12:39 ianmacd Exp $
+# $Id: search.rb,v 1.141 2006/08/08 18:54:03 ianmacd Exp $
 #
 
 require 'amazon'
@@ -64,6 +64,11 @@ module Amazon
     #
     MAX_HEAVY_UPCS	= 10
 
+    # Maximum number of 301 and 302 HTTP responses to follow, should Amazon
+    # later decide to change the location of the service.
+    #
+    MAX_REDIRECTS = 3
+
     # :stopdoc:
 
     # The server to contact for the various Amazon locales.
@@ -270,8 +275,8 @@ module Amazon
     # class from which most others in the library inherit.
     #
     class Request
-      attr_reader   :token, :id, :config
-      attr_accessor :locale, :cache
+      attr_reader   :token, :id, :config, :locale
+      attr_accessor :cache
 
       AWS_PREFIX = '/onca/xml3' # :nodoc:
 
@@ -340,10 +345,15 @@ module Amazon
       #
       #  r = Request.new('D23XFCO2UKJY82', 'foobar-20', 'us', false)
       #  
-      #  # do a bunch of things in the US locale with the cache off, then:
+      #  # Do a bunch of things in the US locale with the cache off, then:
       #  #
-      #  r.locale = 'uk'		      # switch to the UK locale
-      #  r.cache = Cache.new('/tmp/amazon')   # start using a cache
+      #  r.locale = 'uk'		      # Switch to the UK locale
+      #  r.id = 'foobaruk-21'		      # Use a different Associates ID
+      #                                       # in this locale.
+      #  r.cache = Cache.new('/tmp/amazon')   # Start using a cache.
+      #
+      # Note that reassigning the locale will dynamically and transparently
+      # set up a new HTTP connection to the correct server for that locale.
       #
       # You may also put one or more of these parameters in a configuration
       # file, which will be read in the order of <tt>/etc/amazonrc</tt> and
@@ -414,10 +424,7 @@ module Amazon
 
 	# take locale from config file if no locale was passed to method
 	locale = @config['locale'] if @config.key?('locale') && ! def_locale
-
-	unless LOCALES.has_key? locale
-	  raise LocaleError, "invalid locale: #{locale}"
-	end
+	validate_locale(locale)
 
 	if dev_token.nil?
 	  raise TokenError, 'dev_token may not be nil'
@@ -425,7 +432,6 @@ module Amazon
 
 	@token	    = dev_token
 	@id	    = associate || DEFAULT_ID[locale]
-	@locale	    = locale
 	@user_agent = user_agent
 	@cache	    = unless cache == false
 			Amazon::Search::Cache.new(@config['cache_dir'] ||
@@ -433,18 +439,49 @@ module Amazon
 		      else
 			nil
 		      end
-	begin
+	self.locale = locale
+      end
+
+
+      def locale=(l)
+	old_locale = @locale ||= nil
+	@locale = validate_locale(l)
+
+	# Use the new locale's default ID if the ID currently in use is the
+	# current locale's default ID.
+	@id = DEFAULT_ID[@locale] if @id == DEFAULT_ID[old_locale]
+
+	# We must now set up a new HTTP connection to the correct server for
+	# this locale, unless the same server is used for both.
+	connect(@locale) unless LOCALES[@locale] == LOCALES[old_locale]
+      end
+
+
+      # Verify the validity of a locale string.
+      #
+      def validate_locale(l)
+	raise LocaleError, "invalid locale: #{l}" unless LOCALES.has_key? l
+	l
+      end
+      private :validate_locale
+
+
+      # Return an HTTP connection for the current locale.
+      #
+      def connect(locale)
+	if ENV.key? 'http_proxy'
 	  uri = URI.parse(ENV['http_proxy'])
 	  proxy_user = proxy_pass = nil
 	  proxy_user, proxy_pass = uri.userinfo.split(/:/) if uri.userinfo
 	  @conn = Net::HTTP::Proxy(uri.host, uri.port,
 				   proxy_user,
 				   proxy_pass).start(LOCALES[locale])
-	rescue URI::InvalidURIError
+	else
 	  @conn = Net::HTTP::start(LOCALES[locale])
 	end
       end
-
+      private :connect
+ 
 
       # Encode a string, such that it is suitable for HTTP transmission.
       #
@@ -534,7 +571,6 @@ module Amazon
 
 	url = AWS_PREFIX + "?t=%s&ActorSearch=%s&mode=%s&f=xml" +
 	      "&type=%s&dev-t=%s&page=%s"
-	url << "&keywords=" << keyword unless keyword.nil?
 	url << "&price="    << price   unless price.nil?
 	url << get_offer_string(offerings)
  	@type = WEIGHT[weight]
@@ -549,6 +585,7 @@ module Amazon
 
 	mode = localise_mode(mode)
 	url = url % [@id, actor, mode, @type, @token, page] << sort_string
+	url << "&keywords=" << url_encode(keyword) unless keyword.nil?
 
 	search(url, &block)
       end
@@ -564,7 +601,6 @@ module Amazon
 
 	url = AWS_PREFIX + "?t=%s&ArtistSearch=%s&mode=%s&f=xml" +
 	      "&type=%s&dev-t=%s&page=%s"
-	url << "&keywords=" << keyword unless keyword.nil?
 	url << "&price="    << price   unless price.nil?
 	url << get_offer_string(offerings)
  	@type = WEIGHT[weight]
@@ -579,6 +615,7 @@ module Amazon
 
 	mode = localise_mode(mode)
 	url = url % [@id, artist, mode, @type, @token, page] << sort_string
+	url << "&keywords=" << url_encode(keyword) unless keyword.nil?
 
 	search(url, &block)
       end
@@ -621,7 +658,6 @@ module Amazon
 
 	url = AWS_PREFIX + "?t=%s&AuthorSearch=%s&mode=%s&f=xml" +
 	      "&type=%s&dev-t=%s&page=%s"
-	url << "&keywords=" << keyword unless keyword.nil?
 	url << "&price="    << price   unless price.nil?
 	url << "&variations=yes"       if editions == ALL_EDITIONS
 	url << get_offer_string(offerings)
@@ -649,7 +685,7 @@ module Amazon
 
 	url = AWS_PREFIX + "?t=%s&DirectorSearch=%s&mode=%s&f=xml" +
 	      "&type=%s&dev-t=%s&page=%s"
-	url << "&keywords=" << keyword unless keyword.nil?
+	url << "&keywords=" << url_encode(keyword) unless keyword.nil?
 	url << "&price="    << price   unless price.nil?
 	url << get_offer_string(offerings)
  	@type = WEIGHT[weight]
@@ -664,6 +700,7 @@ module Amazon
 
 	mode = localise_mode(mode)
 	url = url % [@id, director, mode, @type, @token, page] << sort_string
+	url << "&keywords=" << url_encode(keyword) unless keyword.nil?
 
 	search(url, &block)
       end
@@ -725,7 +762,6 @@ module Amazon
 
 	url = AWS_PREFIX + "?t=%s&ManufacturerSearch=%s&mode=%s" +
 	      "&f=xml&type=%s&dev-t=%s&page=%s"
-	url << "&keywords=" << keyword unless keyword.nil?
 	url << "&price="    << price   unless price.nil?
 	url << get_offer_string(offerings)
  	@type = WEIGHT[weight]
@@ -741,6 +777,7 @@ module Amazon
 
 	mode = localise_mode(mode)
 	url = url % [@id, director, mode, @type, @token, page] << sort_string
+	url << "&keywords=" << url_encode(keyword) unless keyword.nil?
 
 	search(url, &block)
       end
@@ -757,7 +794,6 @@ module Amazon
 
 	url = AWS_PREFIX + "?t=%s&BrowseNodeSearch=%s&mode=%s&f=xml" +
 	      "&type=%s&dev-t=%s&page=%s"
-	url << "&keywords=" << keyword unless keyword.nil?
 	url << "&price="    << price   unless price.nil?
 	url << get_offer_string(offerings)
  	@type = WEIGHT[weight]
@@ -776,6 +812,7 @@ module Amazon
 	mode = localise_mode(mode)
 	url =
 	  url % [@id, browse_node, mode, @type, @token, page] << sort_string
+	url << "&keywords=" << url_encode(keyword) unless keyword.nil?
 
 	search(url, &block)
       end
@@ -935,6 +972,21 @@ module Amazon
 	Amazon::dprintf("Fetching http://%s%s ...\n", @conn.address, url)
 	response = @conn.get(url, { 'user-agent', @user_agent })
 
+	redirects = 0
+	while response.key?('location')
+	  if (redirects += 1) > MAX_REDIRECTS
+	    raise HTTPError, "More than #{MAX_REDIRECTS} redirections"
+	  end
+
+	  old_url = url
+	  url = URI.parse(response['location'])
+	  url.scheme = old_url.scheme unless url.scheme
+	  url.host = old_url.host unless url.host
+	  Amazon::dprintf("Following HTTP %s to %s ...\n", response.code, url)
+	  response = Net::HTTP::start(url.host).
+		       get(url.path,{ 'user-agent', @user_agent })
+	end
+
 	if response.code != '200'
 	  raise HTTPError, "HTTP response code #{response.code}"
 	end
