@@ -1,4 +1,4 @@
-# $Id: setup.rb,v 1.2 2004/04/17 23:23:50 ianmacd Exp $
+# $Id: setup.rb,v 1.3 2006/08/03 16:53:24 ianmacd Exp $
 
 require 'amazon/search'
 
@@ -6,10 +6,8 @@ include Amazon
 
 class TC_AmazonHTTPTest < Test::Unit::TestCase
 
-  DEV_TOKEN     = "D23XFCO2UKJY82"    # random token
-
   def setup
-    @@req = Search::Request.new(DEV_TOKEN)
+    @@req = Search::Request.new
     @@req.cache = nil
   end
 
