@@ -1,29 +1,30 @@
 #!/usr/bin/ruby -w
 #
-# $Id: tc_accessors.rb,v 1.2 2004/04/17 23:55:48 ianmacd Exp $
+# $Id: tc_accessors.rb,v 1.4 2006/08/03 19:58:34 ianmacd Exp $
 
 $: << File.dirname(__FILE__) + "/../lib"
 
 require 'test/unit'
 require 'amazon/search'
-require './setup'
 
 class TC_Accessors < Test::Unit::TestCase
 
   include Amazon
 
-  DEV_TOKEN     = "D23XFCO2UKJY82"    # random token
- 
   def setup
-    @@req = Search::Request.new(DEV_TOKEN)
+    @@req = Search::Request.new
     @@req.cache = nil
   end
 
   def test_accessors
     assert_nothing_raised { @@req.locale }
+    assert_nothing_raised { @@req.locale = 'ca' }
+    assert_nothing_raised { @@req.locale = 'de' }
+    assert_nothing_raised { @@req.locale = 'fr' }
+    assert_nothing_raised { @@req.locale = 'jp' }
     assert_nothing_raised { @@req.locale = 'uk' }
+    assert_nothing_raised { @@req.locale = 'us' }
     assert_nothing_raised { @@req.cache }
-    assert_nothing_raised { @@req.locale = false }
   end
 
 end
