@@ -1,6 +1,6 @@
 #!/usr/bin/ruby -w
 #
-# $Id: tc_amazon-blended-search.rb,v 1.8 2004/04/17 23:55:48 ianmacd Exp $
+# $Id: tc_amazon-blended-search.rb,v 1.9 2006/08/03 16:53:24 ianmacd Exp $
 
 $: << File.dirname(__FILE__) + "/../lib"
 
@@ -11,10 +11,8 @@ include Amazon
 
 class TC_AmazonHTTPBlendedTest < Test::Unit::TestCase
 
-  DEV_TOKEN     = "D23XFCO2UKJY82"    # random token
-
   def setup
-    @@req = Search::Blended::Request.new(DEV_TOKEN)
+    @@req = Search::Blended::Request.new
     @@req.cache = nil
   end
 
