@@ -1,6 +1,6 @@
 #!/usr/bin/ruby -w
 #
-# $Id: tc_amazon-marketplace-search.rb,v 1.9 2004/09/22 17:16:07 ianmacd Exp $
+# $Id: tc_amazon-marketplace-search.rb,v 1.10 2006/08/03 16:52:00 ianmacd Exp $
 
 $: << File.dirname(__FILE__) + "/../lib"
 
@@ -11,10 +11,8 @@ include Amazon
 
 class TC_AmazonHTTPMarketplaceTest < Test::Unit::TestCase
 
-  DEV_TOKEN     = "D23XFCO2UKJY82"    # random token
-
   def setup
-    @@req = Search::Exchange::Marketplace::Request.new(DEV_TOKEN)
+    @@req = Search::Exchange::Marketplace::Request.new
     @@req.cache = nil
   end
 
@@ -26,7 +24,7 @@ class TC_AmazonHTTPMarketplaceTest < Test::Unit::TestCase
   def test_keyword_search
     [Search::HEAVY, Search::LITE].each do |heaviness|
       heavy = heaviness ? 'heavy' : 'lite'
-      resp = @@req.keyword_search('awful truth', heaviness)
+      resp = @@req.keyword_search('A3R9P1FSNCY7TY', 'awful truth', heaviness)
       assert_kind_of(Amazon::Search::Exchange::Marketplace::Response, resp,
        'could not perform an Amazon::Search::Exchange::Marketplace::Request#listing_search')
       prods = resp.products
@@ -39,7 +37,7 @@ class TC_AmazonHTTPMarketplaceTest < Test::Unit::TestCase
   def test_listing_search
     [Search::HEAVY, Search::LITE].each do |heaviness|
       heavy = heaviness ? 'heavy' : 'lite'
-      resp = @@req.listing_search('0124K463269', heaviness)
+      resp = @@req.listing_search('A3R9P1FSNCY7TY', '0124K463269', heaviness)
       assert_kind_of(Amazon::Search::Exchange::Marketplace::Response, resp,
        'could not perform an Amazon::Search::Exchange::Marketplace::Request#listing_search')
       prods = resp.products[0]
