@@ -1,6 +1,6 @@
 #!/usr/bin/ruby -w
 #
-# $Id: tc_amazon-search-jp.rb,v 1.4 2004/04/17 23:55:48 ianmacd Exp $
+# $Id: tc_amazon-search-jp.rb,v 1.5 2006/08/03 16:53:24 ianmacd Exp $
 
 $: << File.dirname(__FILE__) + "/../lib"
 
@@ -13,10 +13,8 @@ include Amazon
 
 class TC_AmazonJPHTTPTest < Test::Unit::TestCase
 
-  DEV_TOKEN     = "D23XFCO2UKJY82"    # random token
-
   def setup
-    @@req = Search::Request.new(DEV_TOKEN, nil, 'jp')
+    @@req = Search::Request.new(nil, nil, 'jp')
     @@req.cache = nil
   end
 
