@@ -1,6 +1,6 @@
 #!/usr/bin/ruby -w
 #
-# $Id: tc_amazon-weddingregistry.rb,v 1.3 2004/02/26 23:06:19 ianmacd Exp $
+# $Id: tc_amazon-weddingregistry.rb,v 1.4 2006/08/03 19:04:46 ianmacd Exp $
 
 $: << File.dirname(__FILE__) + "/../lib"
 
@@ -13,10 +13,9 @@ include Amazon
 class TC_AmazonWeddingRegistryTest < Test::Unit::TestCase
 
   ASSOC_ID	= "webservices-20"
-  DEV_TOKEN     = "D23XFCO2UKJY82"    # random token
 
   def test_add_item
-    html = WeddingRegistry.add_item_form(DEV_TOKEN, ASSOC_ID, '456')
+    html = WeddingRegistry.add_item_form(nil, ASSOC_ID, '456')
     assert_kind_of(String, html, 'no string returned')
   end
 
