@@ -1,6 +1,6 @@
 #!/usr/bin/ruby -w
 #
-# $Id: tc_amazon-wishlist_search.rb,v 1.4 2004/04/01 10:03:40 ianmacd Exp $
+# $Id: tc_amazon-wishlist_search.rb,v 1.5 2004/09/22 17:15:37 ianmacd Exp $
 
 $: << File.dirname(__FILE__) + "/../lib"
 
@@ -33,7 +33,7 @@ class TC_AmazonHTTPTest
     resp = @@req.wishlist_search('RMPWOC6X3DLC', Search::LITE,
 				 Search::ALL_PAGES)
     assert_kind_of(Amazon::Search::Response, resp,
-	 'could not perform an Amazon::Search::Request#wishlist_search')
+	 'could not retrieve all pages of an Amazon::Search::Request#wishlist_search')
     #resp.products.each {|pr| puts pr.asin }
   end
  
